==> 1.0.6.tar.gz: doc/UserApi.md <==
# forestvpn_api.api.UserApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getPreference**](UserApi.md#getPreference) | **GET** /user/preference/ | Get user preference
[**getPremium**](UserApi.md#getPremium) | **GET** /user/premium/ | Get premium status details
[**updatePreference**](UserApi.md#updatePreference) | **PATCH** /user/preference/ | Update user preference


# **getPreference**
> Preference getPreference()

Get user preference

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = UserApi();

try { 
    var result = api_instance.getPreference();
    print(result);
} catch (e) {
    print("Exception when calling UserApi->getPreference: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**Preference**](Preference.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getPremium**
> Premium getPremium()

Get premium status details

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = UserApi();

try { 
    var result = api_instance.getPremium();
    print(result);
} catch (e) {
    print("Exception when calling UserApi->getPremium: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**Premium**](Premium.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updatePreference**
> Preference updatePreference(request)

Update user preference

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = UserApi();
var request = PreferenceUpdateRequest(); // PreferenceUpdateRequest | 

try { 
    var result = api_instance.updatePreference(request);
    print(result);
} catch (e) {
    print("Exception when calling UserApi->updatePreference: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**PreferenceUpdateRequest**](PreferenceUpdateRequest.md)|  | 

### Return type

[**Preference**](Preference.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> 1.2.1.tar.gz: doc/UserApi.md <==
# forestvpn_api.api.UserApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getPremium**](UserApi.md#getPremium) | **GET** /user/premium/ | Get premium status details
[**getSubscriptions**](UserApi.md#getSubscriptions) | **GET** /user/subscriptions/ | Get subscriptions


# **getPremium**
> Subscription getPremium()

Get premium status details

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = UserApi();

try { 
    var result = api_instance.getPremium();
    print(result);
} catch (e) {
    print("Exception when calling UserApi->getPremium: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**Subscription**](Subscription.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getSubscriptions**
> List<Subscription> getSubscriptions()

Get subscriptions

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = UserApi();

try { 
    var result = api_instance.getSubscriptions();
    print(result);
} catch (e) {
    print("Exception when calling UserApi->getSubscriptions: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List<Subscription>**](Subscription.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
